@@ -17,15 +17,11 @@
 
 package org.apache.inlong.agent.db;
 
-import org.apache.inlong.agent.conf.TriggerProfile;
 import org.apache.inlong.common.constant.Constants;
 import org.apache.inlong.common.db.CommandEntity;
 
 import java.util.List;
 
-import static org.apache.inlong.agent.constant.AgentConstants.DEFAULT_JOB_VERSION;
-import static org.apache.inlong.agent.constant.AgentConstants.JOB_VERSION;
-
 /**
  * Command for database
  */
@@ -51,19 +47,6 @@ public class CommandDb {
         return db.searchCommands(false);
     }
 
-    /**
-     * save normal command result for trigger
-     */
-    public void saveNormalCmds(TriggerProfile profile, boolean success) {
-        CommandEntity entity = new CommandEntity();
-        entity.setId(CommandEntity.generateCommandId(profile.getTriggerId(), profile.getOpType()));
-        entity.setTaskId(Integer.parseInt(profile.getTriggerId()));
-        entity.setCommandResult(success ? Constants.RESULT_SUCCESS : Constants.RESULT_FAIL);
-        entity.setVersion(profile.getInt(JOB_VERSION, DEFAULT_JOB_VERSION));
-        entity.setAcked(false);
-        storeCommand(entity);
-    }
-
     /**
      * save special command result for trigger (retry\makeup\check)
      */
