@@ -36,6 +36,11 @@ export const allDefaultNodes: MetaExportWithBackendList<NodeMetaType> = [
     value: 'CLS',
     LoadEntity: () => import('./Cls'),
   },
+  {
+    label: 'Doris',
+    value: 'DORIS',
+    LoadEntity: () => import('./Doris'),
+  },
   {
     label: 'Elasticsearch',
     value: 'ELASTICSEARCH',
