@@ -24,6 +24,7 @@ import i18n from '@/i18n';
 import EditableTable from '@/ui/components/EditableTable';
 import { fieldTypes as sourceFieldsTypes } from '@/plugins/sinks/common/sourceFields';
 import { statusList, genStatusTag } from './status';
+import { timestampFormat } from '@/core/utils';
 
 const { I18nMap, I18n } = DataWithBackend;
 const { FieldList, FieldDecorator } = RenderRow;
@@ -76,6 +77,12 @@ export class StreamDefaultInfo implements DataWithBackend, RenderRow, RenderList
   readonly creator: string;
 
   @ColumnDecorator()
+  @I18n('basic.Modifier')
+  readonly modifier: string;
+
+  @ColumnDecorator({
+    render: text => timestampFormat(text),
+  })
   @I18n('basic.CreateTime')
   readonly createTime: string;
 
@@ -98,7 +105,7 @@ export class StreamDefaultInfo implements DataWithBackend, RenderRow, RenderList
     type: 'radio',
     initialValue: 'CSV',
     props: values => ({
-      disabled: [110, 130].includes(values?.status),
+      disabled: [110].includes(values?.status),
       options: [
         {
           label: 'CSV',
@@ -128,7 +135,7 @@ export class StreamDefaultInfo implements DataWithBackend, RenderRow, RenderList
     rules: [{ required: true }],
     initialValue: true,
     props: values => ({
-      disabled: [110, 130].includes(values?.status),
+      disabled: [110].includes(values?.status),
       options: [
         {
           label: i18n.t('basic.Yes'),
@@ -148,7 +155,7 @@ export class StreamDefaultInfo implements DataWithBackend, RenderRow, RenderList
     type: 'radio',
     initialValue: 'UTF-8',
     props: values => ({
-      disabled: [110, 130].includes(values?.status),
+      disabled: [110].includes(values?.status),
       options: [
         {
           label: 'UTF-8',
@@ -169,7 +176,7 @@ export class StreamDefaultInfo implements DataWithBackend, RenderRow, RenderList
     type: 'select',
     initialValue: '124',
     props: values => ({
-      disabled: [110, 130].includes(values?.status),
+      disabled: [110].includes(values?.status),
       dropdownMatchSelectWidth: false,
       options: [
         {
@@ -220,7 +227,7 @@ export class StreamDefaultInfo implements DataWithBackend, RenderRow, RenderList
     type: EditableTable,
     props: values => ({
       size: 'small',
-      canDelete: record => !(record.id && [110, 130].includes(values?.status)),
+      canDelete: record => !(record.id && [110].includes(values?.status)),
       canBatchAdd: true,
       columns: [
         {
@@ -234,7 +241,7 @@ export class StreamDefaultInfo implements DataWithBackend, RenderRow, RenderList
             },
           ],
           props: (text, record) => ({
-            disabled: record.id && [110, 130].includes(values?.status),
+            disabled: record.id && [110].includes(values?.status),
           }),
         },
         {
@@ -243,7 +250,7 @@ export class StreamDefaultInfo implements DataWithBackend, RenderRow, RenderList
           type: 'select',
           initialValue: sourceFieldsTypes[0].value,
           props: (text, record) => ({
-            disabled: record.id && [110, 130].includes(values?.status),
+            disabled: record.id && [110].includes(values?.status),
             options: sourceFieldsTypes,
           }),
           rules: [{ required: true }],
@@ -262,24 +269,28 @@ export class StreamDefaultInfo implements DataWithBackend, RenderRow, RenderList
     type: 'radio',
     isPro: true,
     rules: [{ required: true }],
-    initialValue: true,
-    tooltip: i18n.t('meta.Stream.WrapWithInlongMsgHelp'),
+    initialValue: 'INLONG_MSG_V0',
+    tooltip: i18n.t('meta.Stream.WrapTypeHelp'),
     props: values => ({
-      disabled: [110, 130].includes(values?.status),
+      disabled: [110].includes(values?.status),
       options: [
         {
-          label: i18n.t('basic.Yes'),
-          value: true,
+          label: 'InLongMsg V0',
+          value: 'INLONG_MSG_V0',
         },
         {
-          label: i18n.t('basic.No'),
-          value: false,
+          label: 'InLongMsg V1',
+          value: 'INLONG_MSG_V1',
+        },
+        {
+          label: 'Raw',
+          value: 'RAW',
         },
       ],
     }),
   })
-  @I18n('meta.Stream.WrapWithInlongMsg')
-  wrapWithInlongMsg: boolean;
+  @I18n('meta.Stream.WrapType')
+  wrapType: string;
 
   parse(data) {
     return data;
