@@ -65,7 +65,12 @@ const Comp: React.FC<Props> = ({ id, defaultType, ...modalProps }) => {
       inCharges: values.inCharges?.join(','),
       clusterTags: values.clusterTags?.join(','),
     };
-    if (values.type === 'SORT_CLS' || values.type === 'SORT_ES' || values.type === 'SORT_PULSAR') {
+    if (
+      values.type === 'AGENT' ||
+      values.type === 'SORT_CLS' ||
+      values.type === 'SORT_ES' ||
+      values.type === 'SORT_PULSAR'
+    ) {
       submitData.name = values.displayName;
     }
     if (isUpdate) {
