@@ -76,6 +76,9 @@ public class CommonConfigHolder {
     private static final String KEY_CONFIG_CHECK_INTERVAL_MS = "configCheckInterval";
     public static final long VAL_DEF_CONFIG_SYNC_INTERVAL_MS = 60000L;
     public static final long VAL_MIN_CONFIG_SYNC_INTERVAL_MS = 10000L;
+    // max allowed wait duration
+    private static final String KEY_META_CONFIG_SYNC_WAST_ALARM_MS = "meta.config.sync.wast.alarm.ms";
+    public static final long VAL_DEF_META_CONFIG_SYNC_WAST_ALARM_MS = 30000L;
     // whether to startup using the local metadata.json file without connecting to the Manager
     private static final String KEY_ENABLE_STARTUP_USING_LOCAL_META_FILE =
             "startup.using.local.meta.file.enable";
@@ -165,6 +168,7 @@ public class CommonConfigHolder {
     private String managerAuthSecretKey = "";
     private boolean enableStartupUsingLocalMetaFile = VAL_DEF_ENABLE_STARTUP_USING_LOCAL_META_FILE;
     private long metaConfigSyncInvlMs = VAL_DEF_CONFIG_SYNC_INTERVAL_MS;
+    private long metaConfigWastAlarmMs = VAL_DEF_META_CONFIG_SYNC_WAST_ALARM_MS;
     private boolean enableAudit = VAL_DEF_ENABLE_AUDIT;
     private final HashSet<String> auditProxys = new HashSet<>();
     private String auditFilePath = VAL_DEF_AUDIT_FILE_PATH;
@@ -253,6 +257,10 @@ public class CommonConfigHolder {
         return metaConfigSyncInvlMs;
     }
 
+    public long getMetaConfigWastAlarmMs() {
+        return metaConfigWastAlarmMs;
+    }
+
     public boolean isEnableUnConfigTopicAccept() {
         return enableUnConfigTopicAccept;
     }
@@ -409,6 +417,11 @@ public class CommonConfigHolder {
                 this.metaConfigSyncInvlMs = tmpSyncInvMs;
             }
         }
+        // read configure sync wast alarm ms
+        tmpValue = this.props.get(KEY_META_CONFIG_SYNC_WAST_ALARM_MS);
+        if (StringUtils.isNotBlank(tmpValue)) {
+            this.metaConfigWastAlarmMs = NumberUtils.toLong(tmpValue.trim(), VAL_DEF_META_CONFIG_SYNC_WAST_ALARM_MS);
+        }
         // read enable startup using local meta file
         tmpValue = this.props.get(KEY_ENABLE_STARTUP_USING_LOCAL_META_FILE);
         if (StringUtils.isNotEmpty(tmpValue)) {
@@ -423,7 +436,7 @@ public class CommonConfigHolder {
         tmpValue = this.props.get(KEY_UNCONFIGURED_TOPIC_DEFAULT_TOPICS);
         if (StringUtils.isNotBlank(tmpValue)) {
             List<String> tmpList = new ArrayList<>();
-            String[] topicItems = tmpValue.split("\\s+");
+            String[] topicItems = tmpValue.split(",|\\s+");
             for (String item : topicItems) {
                 if (StringUtils.isBlank(item)) {
                     continue;
@@ -463,7 +476,7 @@ public class CommonConfigHolder {
         tmpValue = this.props.get(KEY_FILE_METRIC_STAT_INTERVAL_SEC);
         if (StringUtils.isNotEmpty(tmpValue)) {
             int statInvl = NumberUtils.toInt(tmpValue.trim(), VAL_DEF_FILE_METRIC_STAT_INVL_SEC);
-            if (statInvl >= VAL_MIN_FILE_METRIC_MAX_CACHE_CNT) {
+            if (statInvl >= VAL_MIN_FILE_METRIC_STAT_INVL_SEC) {
                 this.fileMetricStatInvlSec = statInvl;
             }
         }
@@ -471,7 +484,7 @@ public class CommonConfigHolder {
         tmpValue = this.props.get(KEY_FILE_METRIC_MAX_CACHE_CNT);
         if (StringUtils.isNotEmpty(tmpValue)) {
             int maxCacheCnt = NumberUtils.toInt(tmpValue.trim(), VAL_DEF_FILE_METRIC_MAX_CACHE_CNT);
-            if (maxCacheCnt >= VAL_MIN_FILE_METRIC_STAT_INVL_SEC) {
+            if (maxCacheCnt >= VAL_MIN_FILE_METRIC_MAX_CACHE_CNT) {
                 this.fileMetricStatCacheCnt = maxCacheCnt;
             }
         }
