@@ -25,10 +25,6 @@ import java.util.Map;
  */
 public interface IManagerIpListParser {
 
-    String KEY_MANAGER_HOSTS = "manager.hosts";
-    String SEPARATOR = ",";
-    String KEY_MANAGER_TYPE = "manager.type";
-
     void setCommonProperties(Map<String, String> commonProperties);
 
     /**
