@@ -411,6 +411,8 @@ public class MetaConfigHolder extends ConfigHolder {
                     idObject.getParams().getOrDefault("dataType", DataType.TEXT.value())));
             tmpConfig.setFieldDelimiter(idObject.getParams().getOrDefault("fieldDelimiter", "|"));
             tmpConfig.setFileDelimiter(idObject.getParams().getOrDefault("fileDelimiter", "\n"));
+            tmpConfig.setUseExtendedFields(Boolean.valueOf(
+                    idObject.getParams().getOrDefault("useExtendedFields", "false")));
             tmpTopicConfigMap.put(tmpConfig.getUid(), tmpConfig);
             if (mqType.equals(CacheType.TUBE)
                     && !tmpConfig.getUid().equals(tmpConfig.getInlongGroupId())
