@@ -26,23 +26,33 @@ public class StatConstants {
     public static final java.lang.String EVENT_VISIT_OVERMAX = "visit.overmax";
     public static final java.lang.String EVENT_VISIT_LINKIN = "visit.linkin";
     public static final java.lang.String EVENT_VISIT_LINKOUT = "visit.linkout";
-    public static final java.lang.String EVENT_VISIT_EXCEPTION = "visit.exception";
-    // channel
-    public static final java.lang.String EVENT_REMOTE_UNWRITABLE = "socket.unwritable";
+    // link
+    public static final java.lang.String EVENT_LINK_READ_TIMEOUT = "link.read.timeout";
+    public static final java.lang.String EVENT_LINK_FRAME_OVERMAX = "link.frame.overmax";
+    public static final java.lang.String EVENT_LINK_FRAME_CORRPUTED = "link.frame.corrupted";
+    public static final java.lang.String EVENT_LINK_IO_EXCEPTION = "link.io.exception";
+    public static final java.lang.String EVENT_LINK_UNKNOWN_EXCEPTION = "link.unknown.exception";
+    public static final java.lang.String EVENT_LINK_UNWRITABLE = "link.unwritable";
+    // http link
+    public static final java.lang.String EVENT_HTTP_LINK_READ_TIMEOUT = "http.link.read.timeout";
+    public static final java.lang.String EVENT_HTTP_LINK_FRAME_OVERMAX = "http.link.frame.overmax";
+    public static final java.lang.String EVENT_HTTP_LINK_FRAME_CORRPUTED = "http.link.frame.corrupted";
+    public static final java.lang.String EVENT_HTTP_LINK_IO_EXCEPTION = "http.link.io.exception";
+    public static final java.lang.String EVENT_HTTP_LINK_UNKNOWN_EXCEPTION = "http.link.unknown.exception";
+    public static final java.lang.String EVENT_HTTP_LINK_UNWRITABLE = "http.link.unwritable";
     // configure
-    public static final java.lang.String EVENT_CONFIG_TOPIC_MISSING = "config.topic.missing";
+    public static final java.lang.String EVENT_SOURCE_TOPIC_MISSING = "source.topic.missing";
     public static final java.lang.String EVENT_CONFIG_IDNUM_EMPTY = "config.idnum.empty";
     public static final java.lang.String EVENT_CONFIG_GROUPIDNUM_MISSING = "config.groupidnum.missing";
     public static final java.lang.String EVENT_CONFIG_GROUP_IDNUM_INCONSTANT = "config.group.idnum.incons";
     public static final java.lang.String EVENT_CONFIG_STREAMIDNUM_MISSING = "config.streamidnum.missing";
     public static final java.lang.String EVENT_CONFIG_STREAM_IDNUM_INCONSTANT = "config.stream.idnum.incons";
-    // source
-    public static final java.lang.String EVENT_PKG_READABLE_EMPTY = "pkg.readable.empty";
-    public static final java.lang.String EVENT_PKG_READABLE_OVERMAX = "pkg.readable.overmax";
-    public static final java.lang.String EVENT_PKG_READABLE_UNFILLED = "pkg.readable.unfilled";
-    public static final java.lang.String EVENT_PKG_MSGTYPE_V0_INVALID = "pkg.msgtype.v0.invalid";
-    public static final java.lang.String EVENT_PKG_MSGTYPE_V1_INVALID = "pkg.msgtype.v1.invalid";
     // message
+    public static final java.lang.String EVENT_MSG_READABLE_EMPTY = "msg.readable.empty";
+    public static final java.lang.String EVENT_MSG_READABLE_OVERMAX = "msg.readable.overmax";
+    public static final java.lang.String EVENT_MSG_READABLE_UNFILLED = "msg.readable.unfilled";
+    public static final java.lang.String EVENT_MSG_MSGTYPE_V0_INVALID = "msg.msgtype.v0.invalid";
+    public static final java.lang.String EVENT_MSG_MSGTYPE_V1_INVALID = "msg.msgtype.v1.invalid";
     public static final java.lang.String EVENT_MSG_BIN_TOTALLEN_BELOWMIN = "msg.bin.totallen.belowmin";
     public static final java.lang.String EVENT_MSG_TXT_TOTALLEN_BELOWMIN = "msg.txt.totallen.belowmin";
     public static final java.lang.String EVENT_MSG_DECODE_FAIL = "msg.decode.failure";
@@ -81,12 +91,14 @@ public class StatConstants {
     public static final java.lang.String EVENT_SINK_EVENT_V1_MALFORMED = "sink.event.v1.malformed";
     public static final java.lang.String EVENT_SINK_EVENT_TAKE_SUCCESS = "sink.event.take.success";
     public static final java.lang.String EVENT_SINK_EVENT_TAKE_FAILURE = "sink.event.take.failure";
-    public static final java.lang.String EVENT_SINK_EVENT_V1_FILE = "sink.event.v1.file";
-    public static final java.lang.String EVENT_SINK_EVENT_V0_FILE = "sink.event.v1.file";
+    public static final java.lang.String EVENT_SINK_FILE_V1_TAKE_SUCCESS = "sink.file.v1.take.success";
+    public static final java.lang.String EVENT_SINK_FILE_V0_TAKE_SUCCESS = "sink.file.v0.take.success";
     public static final java.lang.String EVENT_SINK_CONFIG_TOPIC_MISSING = "sink.topic.missing";
     public static final java.lang.String EVENT_SINK_DEFAULT_TOPIC_MISSING = "default.topic.empty";
     public static final java.lang.String EVENT_SINK_DEFAULT_TOPIC_USED = "default.topic.used";
     public static final java.lang.String EVENT_SINK_PRODUCER_NULL = "sink.producer.null";
+    public static final java.lang.String EVENT_SINK_PRODUCER_CREATE_SUCCESS = "sink.producer.create.success";
+    public static final java.lang.String EVENT_SINK_PRODUCER_CREATE_FAILURE = "sink.producer.create.failure";
     public static final java.lang.String EVENT_SINK_CLUSTER_EMPTY = "sink.cluster.empty";
     public static final java.lang.String EVENT_SINK_CLUSTER_UNMATCHED = "sink.cluster.unmatched";
     public static final java.lang.String EVENT_SINK_CPRODUCER_NULL = "sink.cluster.producer.null";
