@@ -60,8 +60,6 @@ public class CodecBinMsg extends AbsV0MsgCodec {
     private long dataTimeSec;
     private boolean num2name = false;
     private boolean transNum2Name = false;
-    private boolean indexMsg = false;
-    private boolean fileCheckMsg = false;
     private boolean needTraceMsg = false;
 
     public CodecBinMsg(int totalDataLen, int msgTypeValue,
@@ -236,7 +234,8 @@ public class CodecBinMsg extends AbsV0MsgCodec {
         InLongMsg inLongMsg = InLongMsg.newInLongMsg(source.isCompressed(), 4);
         inLongMsg.addMsg(dataBuf.array());
         byte[] inlongMsgData = inLongMsg.buildArray();
-        Event event = EventBuilder.withBody(inlongMsgData, buildEventHeaders(inLongMsg.getCreatetime()));
+        msgPkgTime = inLongMsg.getCreatetime();
+        Event event = EventBuilder.withBody(inlongMsgData, buildEventHeaders(source));
         if (isOrderOrProxy) {
             event = new SinkRspEvent(event, MsgType.MSG_BIN_MULTI_BODY, channel);
         }
@@ -260,7 +259,7 @@ public class CodecBinMsg extends AbsV0MsgCodec {
             String confStreamId;
             String strGroupIdNum = String.valueOf(this.groupIdNum);
             confGroupId = configManager.getGroupIdNameByNum(strGroupIdNum);
-            if (StringUtils.isBlank(confGroupId)) {
+            if (StringUtils.isEmpty(confGroupId)) {
                 if (configManager.isGroupIdNumConfigEmpty()) {
                     source.fileMetricIncSumStats(StatConstants.EVENT_CONFIG_IDNUM_EMPTY);
                     this.errCode = DataProxyErrCode.CONF_SERVICE_UNREADY;
@@ -292,7 +291,7 @@ public class CodecBinMsg extends AbsV0MsgCodec {
             } else {
                 String strStreamIdNum = String.valueOf(this.streamIdNum);
                 confStreamId = configManager.getStreamIdNameByIdNum(strGroupIdNum, strStreamIdNum);
-                if (StringUtils.isBlank(confStreamId)) {
+                if (StringUtils.isEmpty(confStreamId)) {
                     if (configManager.isStreamIdNumConfigEmpty()) {
                         source.fileMetricIncSumStats(StatConstants.EVENT_CONFIG_IDNUM_EMPTY);
                         this.errCode = DataProxyErrCode.CONF_SERVICE_UNREADY;
@@ -328,8 +327,8 @@ public class CodecBinMsg extends AbsV0MsgCodec {
         }
         // get and check topic configure
         this.topicName = configManager.getTopicName(this.groupId, this.streamId);
-        if (StringUtils.isBlank(this.topicName)) {
-            source.fileMetricIncSumStats(StatConstants.EVENT_CONFIG_TOPIC_MISSING);
+        if (StringUtils.isEmpty(this.topicName)) {
+            source.fileMetricIncWithDetailStats(StatConstants.EVENT_SOURCE_TOPIC_MISSING, this.groupId);
             this.errCode = DataProxyErrCode.TOPIC_IS_BLANK;
             this.errMsg = String.format("Topic not configured for groupId=(%s), streamId=(%s)",
                     this.groupId, this.streamId);
