@@ -242,7 +242,7 @@ public class InlongGroupImpl implements InlongGroup {
         }
         boolean isDeleted = groupClient.deleteInlongGroup(groupInfo.getInlongGroupId(), async);
         if (isDeleted) {
-            groupInfo.setStatus(GroupStatus.DELETED.getCode());
+            groupInfo.setStatus(GroupStatus.CONFIG_DELETED.getCode());
         }
         return generateSnapshot();
     }
@@ -277,7 +277,7 @@ public class InlongGroupImpl implements InlongGroup {
         // if current group is not exists, set its status to deleted
         if (groupInfo == null) {
             groupInfo = groupContext.getGroupInfo();
-            groupInfo.setStatus(GroupStatus.DELETED.getCode());
+            groupInfo.setStatus(GroupStatus.CONFIG_DELETED.getCode());
             return new InlongGroupContext(groupContext);
         }
 
