@@ -32,7 +32,10 @@ public class ClusterType {
     public static final String PULSAR = "PULSAR";
     public static final String DATAPROXY = "DATAPROXY";
     public static final String KAFKA = "KAFKA";
-    public static final String ELASTICSEARCH = "ELASTICSEARCH";
+
+    public static final String SORT_ES = "SORT_ES";
+    public static final String SORT_CLS = "SORT_CLS";
+    public static final String SORT_PULSAR = "SORT_PULSAR";
 
     private static final Set<String> TYPE_SET = new HashSet<String>() {
 
@@ -42,7 +45,9 @@ public class ClusterType {
             add(ClusterType.PULSAR);
             add(ClusterType.DATAPROXY);
             add(ClusterType.KAFKA);
-            add(ClusterType.ELASTICSEARCH);
+            add(ClusterType.SORT_ES);
+            add(ClusterType.SORT_CLS);
+            add(ClusterType.SORT_PULSAR);
         }
     };
 
