@@ -151,6 +151,10 @@ public enum ErrorCodeEnum {
 
     AUDIT_ID_TYPE_NOT_SUPPORTED(4001, "Audit id type '%s' not supported"),
 
+    AUDIT_SOURCE_TYPE_NOT_SUPPORTED(4002, "Audit Source type '%s' not supported"),
+
+    AUDIT_SOURCE_URL_NOT_SUPPORTED(4003, "Audit Source URL '%s' not supported"),
+
     TENANT_NOT_EXIST(5001, "Tenant '%s' is not exist"),
     ;
 
