@@ -39,9 +39,9 @@ public enum SimpleGroupStatus {
             case TO_BE_SUBMIT:
             case TO_BE_APPROVAL:
                 return CREATE;
-            case DELETING:
-            case SUSPENDING:
-            case RESTARTING:
+            case CONFIG_DELETING:
+            case CONFIG_OFFLINE_ING:
+            case CONFIG_ONLINE_ING:
                 return OPERATING;
             case APPROVE_REJECTED:
                 return REJECTED;
@@ -51,13 +51,12 @@ public enum SimpleGroupStatus {
             case CONFIG_FAILED:
                 return FAILED;
             case CONFIG_SUCCESSFUL:
-            case RESTARTED:
                 return STARTED;
-            case SUSPENDED:
+            case CONFIGURATION_OFFLINE:
                 return STOPPED;
             case FINISH:
                 return FINISHED;
-            case DELETED:
+            case CONFIG_DELETED:
                 return DELETED;
             default:
                 throw new IllegalArgumentException(String.format("Unsupported status %s for group", code));
@@ -83,9 +82,9 @@ public enum SimpleGroupStatus {
                 statusList.add(GroupStatus.TO_BE_SUBMIT.getCode());
                 return statusList;
             case OPERATING:
-                statusList.add(GroupStatus.DELETING.getCode());
-                statusList.add(GroupStatus.SUSPENDING.getCode());
-                statusList.add(GroupStatus.RESTARTING.getCode());
+                statusList.add(GroupStatus.CONFIG_DELETING.getCode());
+                statusList.add(GroupStatus.CONFIG_OFFLINE_ING.getCode());
+                statusList.add(GroupStatus.CONFIG_ONLINE_ING.getCode());
                 return statusList;
             case REJECTED:
                 statusList.add(GroupStatus.APPROVE_REJECTED.getCode());
@@ -99,17 +98,16 @@ public enum SimpleGroupStatus {
                 statusList.add(GroupStatus.CONFIG_FAILED.getCode());
                 return statusList;
             case STARTED:
-                statusList.add(GroupStatus.RESTARTED.getCode());
                 statusList.add(GroupStatus.CONFIG_SUCCESSFUL.getCode());
                 return statusList;
             case STOPPED:
-                statusList.add(GroupStatus.SUSPENDED.getCode());
+                statusList.add(GroupStatus.CONFIGURATION_OFFLINE.getCode());
                 return statusList;
             case FINISHED:
                 statusList.add(GroupStatus.FINISH.getCode());
                 return statusList;
             case DELETED:
-                statusList.add(GroupStatus.DELETED.getCode());
+                statusList.add(GroupStatus.CONFIG_DELETED.getCode());
                 return statusList;
             default:
                 throw new IllegalArgumentException(String.format("Unsupported status %s for inlong group", status));
