@@ -101,7 +101,11 @@ public class StartupSortListener implements SortOperateListener {
             List<StreamSink> sinkList = streamInfo.getSinkList();
             List<String> sinkTypes = sinkList.stream().map(StreamSink::getSinkType).collect(Collectors.toList());
             if (CollectionUtils.isEmpty(sinkList) || !SinkType.containSortFlinkSink(sinkTypes)) {
-                return ListenerResult.success();
+                log.warn("not any valid sink configured for groupId {} and streamId {}, reason: {},"
+                        + " skip launching sort job",
+                        CollectionUtils.isEmpty(sinkList) ? "no sink configured" : "no sort flink sink configured",
+                        groupId, streamInfo.getInlongStreamId());
+                continue;
             }
 
             List<InlongStreamExtInfo> extList = streamInfo.getExtList();
