@@ -17,17 +17,20 @@
 
 package org.apache.inlong.manager.pojo.sink.redis;
 
-import io.swagger.annotations.ApiModelProperty;
-import lombok.AllArgsConstructor;
-import lombok.Builder;
-import lombok.Data;
-import lombok.NoArgsConstructor;
 import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
 import org.apache.inlong.manager.common.exceptions.BusinessException;
 import org.apache.inlong.manager.common.util.CommonBeanUtils;
 import org.apache.inlong.manager.common.util.JsonUtils;
 
+import io.swagger.annotations.ApiModelProperty;
+import lombok.AllArgsConstructor;
+import lombok.Builder;
+import lombok.Data;
+import lombok.NoArgsConstructor;
+import org.apache.commons.lang3.StringUtils;
+
 import javax.validation.constraints.NotNull;
+
 import java.util.Map;
 
 /**
@@ -113,8 +116,11 @@ public class RedisSinkDTO {
     /**
      * Get the dto instance from the request
      */
-    public static RedisSinkDTO getFromRequest(RedisSinkRequest request) throws Exception {
-        return CommonBeanUtils.copyProperties(request, RedisSinkDTO::new);
+    public static RedisSinkDTO getFromRequest(RedisSinkRequest request, String extParams) throws Exception {
+        RedisSinkDTO dto = StringUtils.isNotBlank(extParams)
+                ? RedisSinkDTO.getFromJson(extParams)
+                : new RedisSinkDTO();
+        return CommonBeanUtils.copyProperties(request, dto, true);
     }
 
     public static RedisSinkDTO getFromJson(@NotNull String extParams) {
