@@ -18,6 +18,7 @@
 package org.apache.inlong.manager.pojo.sort.node.base;
 
 import org.apache.inlong.common.enums.DataTypeEnum;
+import org.apache.inlong.common.enums.MessageWrapType;
 import org.apache.inlong.manager.common.fieldtype.strategy.FieldTypeMappingStrategy;
 import org.apache.inlong.manager.pojo.sort.util.FieldInfoUtils;
 import org.apache.inlong.manager.pojo.stream.StreamField;
@@ -33,6 +34,7 @@ import org.apache.inlong.sort.protocol.node.format.InLongMsgFormat;
 import org.apache.inlong.sort.protocol.node.format.JsonFormat;
 import org.apache.inlong.sort.protocol.node.format.RawFormat;
 
+import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
 
 import java.util.List;
@@ -74,6 +76,9 @@ public interface ExtractNodeProvider extends NodeProvider {
      */
     default List<FieldInfo> parseStreamFieldInfos(List<StreamField> streamFields, String nodeId,
             FieldTypeMappingStrategy fieldTypeMappingStrategy) {
+        if (CollectionUtils.isEmpty(streamFields)) {
+            return null;
+        }
         // Filter constant fields
         return streamFields.stream().filter(s -> Objects.isNull(s.getFieldValue()))
                 .map(streamFieldInfo -> FieldInfoUtils
@@ -92,7 +97,7 @@ public interface ExtractNodeProvider extends NodeProvider {
      */
     default Format parsingFormat(
             String serializationType,
-            boolean wrapWithInlongMsg,
+            String wrapType,
             String separatorStr,
             boolean ignoreParseErrors) {
         Format format;
@@ -129,7 +134,7 @@ public interface ExtractNodeProvider extends NodeProvider {
             default:
                 throw new IllegalArgumentException(String.format("Unsupported dataType=%s", dataType));
         }
-        if (wrapWithInlongMsg) {
+        if (Objects.equals(wrapType, MessageWrapType.INLONG_MSG_V0.getName())) {
             Format innerFormat = format;
             format = new InLongMsgFormat(innerFormat, false);
         }
