@@ -17,6 +17,7 @@
 
 package org.apache.inlong.manager.pojo.source.kafka;
 
+import org.apache.inlong.common.enums.MessageWrapType;
 import org.apache.inlong.manager.common.consts.SourceType;
 import org.apache.inlong.manager.common.util.CommonBeanUtils;
 import org.apache.inlong.manager.common.util.JsonTypeDefine;
@@ -66,7 +67,7 @@ public class KafkaSource extends StreamSource {
     private String timestampMillis;
 
     @ApiModelProperty(value = "The strategy of auto offset reset", notes = "including earliest, specific, latest (the default), none")
-    private String autoOffsetReset;
+    private String autoOffsetReset = KafkaOffset.LATEST.getName();
 
     @ApiModelProperty("database pattern used for filter in canal format")
     private String databasePattern;
@@ -92,8 +93,8 @@ public class KafkaSource extends StreamSource {
     @ApiModelProperty(value = "Data field escape symbol")
     private String dataEscapeChar;
 
-    @ApiModelProperty("Whether wrap content with InlongMsg")
-    private boolean wrapWithInlongMsg = true;
+    @ApiModelProperty(value = "The message body wrap  wrap type, including: RAW, INLONG_MSG_V0, INLONG_MSG_V1, etc")
+    private String wrapType = MessageWrapType.INLONG_MSG_V0.getName();
 
     public KafkaSource() {
         this.setSourceType(SourceType.KAFKA);
