@@ -45,8 +45,17 @@ public class InlongStreamExtParam implements Serializable {
     @ApiModelProperty(value = "Whether to ignore the parse errors of field value")
     private boolean ignoreParseError;
 
-    @ApiModelProperty(value = "Whether the message body wrapped with InlongMsg")
-    private boolean wrapWithInlongMsg;
+    @ApiModelProperty(value = "If use extended fields")
+    private Boolean useExtendedFields = false;
+
+    @ApiModelProperty(value = "Predefined fields")
+    private String predefinedFields;
+
+    @ApiModelProperty("The multiple enable of sink")
+    private Boolean sinkMultipleEnable = false;
+
+    @ApiModelProperty(value = "Extended field size")
+    private Integer extendedFieldSize = 0;
 
     /**
      * Pack extended attributes into ExtParams
