@@ -19,6 +19,7 @@ package org.apache.inlong.manager.service.cluster;
 
 import org.apache.inlong.common.constant.Constants;
 import org.apache.inlong.common.constant.MQType;
+import org.apache.inlong.common.heartbeat.ReportResourceType;
 import org.apache.inlong.common.pojo.audit.AuditConfig;
 import org.apache.inlong.common.pojo.audit.MQInfo;
 import org.apache.inlong.common.pojo.dataproxy.DataProxyCluster;
@@ -60,6 +61,7 @@ import org.apache.inlong.manager.pojo.cluster.ClusterTagResponse;
 import org.apache.inlong.manager.pojo.cluster.TenantClusterTagInfo;
 import org.apache.inlong.manager.pojo.cluster.TenantClusterTagPageRequest;
 import org.apache.inlong.manager.pojo.cluster.TenantClusterTagRequest;
+import org.apache.inlong.manager.pojo.cluster.dataproxy.DataProxyClusterNodeDTO;
 import org.apache.inlong.manager.pojo.cluster.pulsar.PulsarClusterDTO;
 import org.apache.inlong.manager.pojo.common.PageResult;
 import org.apache.inlong.manager.pojo.common.UpdateResult;
@@ -71,6 +73,8 @@ import org.apache.inlong.manager.pojo.tenant.InlongTenantInfo;
 import org.apache.inlong.manager.pojo.user.InlongRoleInfo;
 import org.apache.inlong.manager.pojo.user.LoginUserUtils;
 import org.apache.inlong.manager.pojo.user.UserInfo;
+import org.apache.inlong.manager.service.cluster.node.InlongClusterNodeInstallOperator;
+import org.apache.inlong.manager.service.cluster.node.InlongClusterNodeInstallOperatorFactory;
 import org.apache.inlong.manager.service.cluster.node.InlongClusterNodeOperator;
 import org.apache.inlong.manager.service.cluster.node.InlongClusterNodeOperatorFactory;
 import org.apache.inlong.manager.service.repository.DataProxyConfigRepository;
@@ -137,6 +141,8 @@ public class InlongClusterServiceImpl implements InlongClusterService {
     private InlongRoleService inlongRoleService;
     @Autowired
     private TenantRoleService tenantRoleService;
+    @Autowired
+    private InlongClusterNodeInstallOperatorFactory clusterNodeInstallOperatorFactory;
 
     @Lazy
     @Autowired
@@ -864,7 +870,13 @@ public class InlongClusterServiceImpl implements InlongClusterService {
             throw new BusinessException(errMsg);
         }
         InlongClusterNodeOperator instance = clusterNodeOperatorFactory.getInstance(request.getType());
-        return instance.saveOpt(request, operator);
+        Integer id = instance.saveOpt(request, operator);
+        if (request.getIsInstall()) {
+            InlongClusterNodeInstallOperator clusterNodeInstallOperator = clusterNodeInstallOperatorFactory.getInstance(
+                    request.getType());
+            clusterNodeInstallOperator.install(request, operator);
+        }
+        return id;
     }
 
     @Override
@@ -920,7 +932,10 @@ public class InlongClusterServiceImpl implements InlongClusterService {
         Page<InlongClusterNodeEntity> entityPage =
                 (Page<InlongClusterNodeEntity>) clusterNodeMapper.selectByCondition(request);
         PageResult<ClusterNodeResponse> pageResult = PageResult.fromPage(entityPage)
-                .map(entity -> CommonBeanUtils.copyProperties(entity, ClusterNodeResponse::new));
+                .map(entity -> {
+                    InlongClusterNodeOperator instance = clusterNodeOperatorFactory.getInstance(entity.getType());
+                    return instance.getFromEntity(entity);
+                });
 
         LOGGER.debug("success to list inlong cluster node by {}", request);
         return pageResult;
@@ -1063,6 +1078,11 @@ public class InlongClusterServiceImpl implements InlongClusterService {
         // update record
         InlongClusterNodeOperator instance = clusterNodeOperatorFactory.getInstance(request.getType());
         instance.updateOpt(request, operator);
+        if (request.getIsInstall()) {
+            InlongClusterNodeInstallOperator clusterNodeInstallOperator = clusterNodeInstallOperatorFactory.getInstance(
+                    request.getType());
+            clusterNodeInstallOperator.install(request, operator);
+        }
         return true;
     }
 
@@ -1122,6 +1142,17 @@ public class InlongClusterServiceImpl implements InlongClusterService {
         return true;
     }
 
+    @Override
+    public Boolean unloadNode(Integer id, String operator) {
+        LOGGER.info("begin to unload inlong cluster node={}, operator={}", id, operator);
+        InlongClusterNodeEntity clusterNodeEntity = clusterNodeMapper.selectById(id);
+        InlongClusterNodeInstallOperator clusterNodeInstallOperator = clusterNodeInstallOperatorFactory.getInstance(
+                clusterNodeEntity.getType());
+        boolean isSuccess = clusterNodeInstallOperator.unload(clusterNodeEntity, operator);
+        LOGGER.info("success to unload inlong cluster node={}, operator={}", id, operator);
+        return isSuccess;
+    }
+
     @Override
     public Boolean deleteNode(Integer id, UserInfo opInfo) {
         InlongClusterNodeEntity entity = clusterNodeMapper.selectById(id);
@@ -1156,10 +1187,12 @@ public class InlongClusterServiceImpl implements InlongClusterService {
         // TODO consider the data proxy load and re-balance
         List<DataProxyNodeInfo> nodeList = new ArrayList<>();
         for (InlongClusterNodeEntity nodeEntity : nodeEntities) {
-            if (Objects.equals(nodeEntity.getStatus(), NodeStatus.HEARTBEAT_TIMEOUT.getStatus())) {
-                LOGGER.debug("dataproxy node was timeout, parentId={} ip={} port={}", nodeEntity.getParentId(),
-                        nodeEntity.getIp(), nodeEntity.getPort());
-                continue;
+            if (StringUtils.isNotBlank(nodeEntity.getExtParams())) {
+                DataProxyClusterNodeDTO dataProxyClusterNodeDTO = DataProxyClusterNodeDTO.getFromJson(
+                        nodeEntity.getExtParams());
+                if (Objects.equals(dataProxyClusterNodeDTO.getEnabledOnline(), false)) {
+                    continue;
+                }
             }
             DataProxyNodeInfo nodeInfo = new DataProxyNodeInfo();
             nodeInfo.setId(nodeEntity.getId());
@@ -1178,6 +1211,63 @@ public class InlongClusterServiceImpl implements InlongClusterService {
         return response;
     }
 
+    @Override
+    public DataProxyNodeResponse getDataProxyNodesByCluster(String clusterName, String protocolType,
+            String reportSourceType) {
+        LOGGER.debug("begin to get data proxy nodes for clusterName={}, protocol={}", clusterName, protocolType);
+        InlongClusterEntity clusterEntity = clusterMapper.selectByNameAndType(clusterName, ClusterType.DATAPROXY);
+        DataProxyNodeResponse response = new DataProxyNodeResponse();
+        if (clusterEntity == null) {
+            LOGGER.debug("not any dataproxy cluster for clusterName={}, protocol={}", clusterName, protocolType);
+            return response;
+        }
+        List<InlongClusterNodeEntity> nodeEntities =
+                clusterNodeMapper.selectByParentId(clusterEntity.getId(), protocolType);
+        if (CollectionUtils.isEmpty(nodeEntities)) {
+            LOGGER.debug("not any data proxy node for clusterName={}, protocol={}", clusterName, protocolType);
+            return response;
+        }
+        // all cluster nodes belong to the same clusterId
+        response.setClusterId(clusterEntity.getId());
+        // TODO consider the data proxy load and re-balance
+        List<DataProxyNodeInfo> nodeList = new ArrayList<>();
+        for (InlongClusterNodeEntity nodeEntity : nodeEntities) {
+            if (Objects.equals(nodeEntity.getStatus(), NodeStatus.HEARTBEAT_TIMEOUT.getStatus())) {
+                LOGGER.debug("dataproxy node was timeout, parentId={} ip={} port={}", nodeEntity.getParentId(),
+                        nodeEntity.getIp(), nodeEntity.getPort());
+                continue;
+            }
+            if (StringUtils.isNotBlank(nodeEntity.getExtParams())) {
+                DataProxyClusterNodeDTO dataProxyClusterNodeDTO = DataProxyClusterNodeDTO.getFromJson(
+                        nodeEntity.getExtParams());
+                if (StringUtils.isBlank(dataProxyClusterNodeDTO.getReportSourceType())) {
+                    dataProxyClusterNodeDTO.setReportSourceType(ReportResourceType.INLONG);
+                }
+                if (StringUtils.isNotBlank(reportSourceType) && !Objects.equals(
+                        dataProxyClusterNodeDTO.getReportSourceType(), reportSourceType)) {
+                    continue;
+                }
+                if (Objects.equals(dataProxyClusterNodeDTO.getEnabledOnline(), false)) {
+                    continue;
+                }
+            }
+            DataProxyNodeInfo nodeInfo = new DataProxyNodeInfo();
+            nodeInfo.setId(nodeEntity.getId());
+            nodeInfo.setIp(nodeEntity.getIp());
+            nodeInfo.setPort(nodeEntity.getPort());
+            nodeInfo.setProtocolType(nodeEntity.getProtocolType());
+            nodeInfo.setNodeLoad(nodeEntity.getNodeLoad());
+            nodeList.add(nodeInfo);
+        }
+        response.setNodeList(nodeList);
+
+        if (LOGGER.isDebugEnabled()) {
+            LOGGER.debug("success to get dp nodes for clusterName={}, protocol={}, result={}",
+                    clusterName, protocolType, response);
+        }
+        return response;
+    }
+
     private List<InlongClusterNodeEntity> getClusterNodes(String groupId, String clusterType, String protocolType) {
         InlongGroupEntity groupEntity = groupMapper.selectByGroupId(groupId);
         if (groupEntity == null) {
