@@ -110,6 +110,7 @@ public abstract class AbstractGroupOperator implements InlongGroupOperator {
     @Transactional(rollbackFor = Throwable.class, isolation = Isolation.REPEATABLE_READ)
     public void updateOpt(InlongGroupRequest request, String operator) {
         InlongGroupEntity entity = groupMapper.selectByGroupId(request.getInlongGroupId());
+        CommonBeanUtils.copyProperties(request, entity, true);
         // set the ext params
         setTargetEntity(request, entity);
         entity.setModifier(operator);
@@ -131,6 +132,7 @@ public abstract class AbstractGroupOperator implements InlongGroupOperator {
     @Override
     public Map<String, Object> getClusterInfoByTag(String clusterTag) {
         Map<String, Object> clusterMap = new HashMap<>();
+        clusterMap.put("inlongClusterTag", clusterTag);
         Set<String> mqClusters = Sets.newHashSet(ClusterType.PULSAR, ClusterType.TUBEMQ, ClusterType.KAFKA);
         List<InlongClusterEntity> clusterEntities = clusterEntityMapper.selectByClusterTag(clusterTag);
         for (InlongClusterEntity clusterEntity : clusterEntities) {
