@@ -112,7 +112,7 @@ public class PulsarOperator {
         LOGGER.info("begin to create namespace={}", tenantNamespaceName);
         try {
             // Check whether the namespace exists, and create it if it does not exist
-            boolean isExists = this.namespaceExists(pulsarClusterInfo, tenant, namespace);
+            boolean isExists = this.namespaceExists(pulsarClusterInfo, tenant, tenantNamespaceName);
             if (isExists) {
                 LOGGER.warn("namespace={} already exists, skip to create", tenantNamespaceName);
                 return;
@@ -467,6 +467,20 @@ public class PulsarOperator {
         return briefMQMessages;
     }
 
+    /**
+     * Reset cursor for consumer group.
+     */
+    public void resetCursor(PulsarClusterInfo pulsarClusterInfo, String topicFullName, String subName,
+            Long resetTime) {
+        try {
+            PulsarUtils.resetCursor(restTemplate, pulsarClusterInfo, topicFullName, subName,
+                    resetTime);
+        } catch (Exception e) {
+            LOGGER.error("failed reset cursor consumer:", e);
+            throw new BusinessException("failed reset cursor consumer:" + e.getMessage());
+        }
+    }
+
     /**
      * Build topicName Of Partition
      */
