@@ -17,7 +17,7 @@
 
 package org.apache.inlong.manager.service.resource.queue.tubemq;
 
-import org.apache.inlong.common.enums.DataProxyMsgEncType;
+import org.apache.inlong.common.enums.MessageWrapType;
 import org.apache.inlong.manager.common.consts.InlongConstants;
 import org.apache.inlong.manager.common.exceptions.BusinessException;
 import org.apache.inlong.manager.common.util.HttpUtils;
@@ -288,7 +288,7 @@ public class TubeMQOperator {
             String url = "http://" + brokerUrl + QUERY_MESSAGE_PATH + TOPIC_NAME + topicName + MSG_COUNT + msgCount;
             TubeMessageResponse response = HttpUtils.request(restTemplate, url, HttpMethod.GET,
                     null, new HttpHeaders(), TubeMessageResponse.class);
-            if (response.getErrCode() != SUCCESS_CODE) {
+            if (response.getErrCode() != SUCCESS_CODE && response.getErrCode() != 200) {
                 String msg = String.format("failed to query message for topic %s, error: %s",
                         topicName, response.getErrMsg());
                 LOGGER.error(msg + " in {} for broker {}", masterUrl, brokerUrl);
@@ -303,10 +303,10 @@ public class TubeMQOperator {
                 }
 
                 int wrapTypeId = Integer.parseInt(map.getOrDefault(InlongConstants.MSG_ENCODE_VER,
-                        Integer.toString(DataProxyMsgEncType.MSG_ENCODE_TYPE_INLONGMSG.getId())));
+                        Integer.toString(MessageWrapType.INLONG_MSG_V0.getId())));
                 byte[] messageData = Base64.getDecoder().decode(tubeDataInfo.getData());
                 DeserializeOperator deserializeOperator = deserializeOperatorFactory.getInstance(
-                        DataProxyMsgEncType.valueOf(wrapTypeId));
+                        MessageWrapType.valueOf(wrapTypeId));
                 messageList.addAll(deserializeOperator.decodeMsg(streamInfo, messageData, map, index));
             }
 
