@@ -233,6 +233,7 @@ CREATE TABLE IF NOT EXISTS `inlong_stream`
     `description`      varchar(256)          DEFAULT '' COMMENT 'Description of inlong stream',
     `mq_resource`      varchar(128)          DEFAULT NULL COMMENT 'MQ resource, in one stream, corresponding to the filter ID of TubeMQ, corresponding to the topic of Pulsar',
     `data_type`        varchar(20)           DEFAULT NULL COMMENT 'Data type, including: CSV, KEY-VALUE, JSON, AVRO, etc.',
+    `wrap_type`        varchar(256)          DEFAULT 'INLONG_MSG_V0' COMMENT 'The message body wrap type, including: RAW, INLONG_MSG_V0, INLONG_MSG_V1, etc',
     `data_encoding`    varchar(8)            DEFAULT 'UTF-8' COMMENT 'Data encoding format, including: UTF-8, GBK, etc.',
     `data_separator`   varchar(8)            DEFAULT NULL COMMENT 'The source data field separator',
     `data_escape_char` varchar(8)            DEFAULT NULL COMMENT 'Source data field escape character, the default is NULL (NULL), stored as 1 character',
@@ -301,6 +302,9 @@ CREATE TABLE IF NOT EXISTS `operation_log`
 (
     `id`                  int(11)   NOT NULL AUTO_INCREMENT,
     `authentication_type` varchar(64)        DEFAULT NULL COMMENT 'Authentication type',
+    `inlong_group_id`     varchar(256)       DEFAULT NULL COMMENT 'Inlong group id',
+    `inlong_stream_id`    varchar(256)       DEFAULT NULL COMMENT 'Inlong stream id',
+    `operation_target`    varchar(256)       DEFAULT NULL COMMENT 'Operation target',
     `operation_type`      varchar(256)       DEFAULT NULL COMMENT 'Operation type',
     `http_method`         varchar(64)        DEFAULT NULL COMMENT 'Request method',
     `invoke_method`       varchar(256)       DEFAULT NULL COMMENT 'Invoke method',
@@ -825,8 +829,8 @@ VALUES ('audit_sdk_collect', 'SDK', 0, '1'),
        ('audit_sort_hive_output', 'HIVE', 1, '8'),
        ('audit_sort_clickhouse_input', 'CLICKHOUSE', 0, '9'),
        ('audit_sort_clickhouse_output', 'CLICKHOUSE', 1, '10'),
-       ('audit_sort_es_input', 'ELASTICSEARCH', 0, '11'),
-       ('audit_sort_es_output', 'ELASTICSEARCH', 1, '12'),
+       ('audit_sort_es_input', 'ES', 0, '11'),
+       ('audit_sort_es_output', 'ES', 1, '12'),
        ('audit_sort_starrocks_input', 'STARROCKS', 0, '13'),
        ('audit_sort_starrocks_output', 'STARROCKS', 1, '14'),
        ('audit_sort_hudi_input', 'HUDI', 0, '15'),
@@ -842,7 +846,13 @@ VALUES ('audit_sdk_collect', 'SDK', 0, '1'),
        ('audit_sort_kudu_input', 'KUDU', 0, '25'),
        ('audit_sort_kudu_output', 'KUDU', 1, '26'),
        ('audit_sort_postgres_input', 'POSTGRESQL', 0, '27'),
-       ('audit_sort_postgres_output', 'POSTGRESQL', 1, '28');
+       ('audit_sort_postgres_output', 'POSTGRESQL', 1, '28'),
+       ('audit_sort_mysql_binlog_input', 'MYSQL_BINLOG', 0, '29'),
+       ('audit_sort_mysql_binlog_output', 'MYSQL_BINLOG', 1, '30'),
+       ('audit_sort_pulsar_input', 'PULSAR', 0, '31'),
+       ('audit_sort_pulsar_output', 'PULSAR', 1, '32'),
+       ('audit_sort_tube_input', 'TUBEMQ', 0, '33'),
+       ('audit_sort_tube_output', 'TUBEMQ', 1, '34');
 
 -- ----------------------------
 -- Table structure for audit_source
