@@ -17,6 +17,8 @@
 
 package org.apache.inlong.sdk.dataproxy.config;
 
+import java.util.Objects;
+
 public class HostInfo implements Comparable<HostInfo>, java.io.Serializable {
 
     private final String referenceName;
@@ -50,9 +52,14 @@ public class HostInfo implements Comparable<HostInfo>, java.io.Serializable {
         return referenceName.compareTo(other.getReferenceName());
     }
 
+    @Override
+    public int hashCode() {
+        return Objects.hash(referenceName, hostName, portNumber);
+    }
+
     @Override
     public boolean equals(Object other) {
-        if (other == null || !(other instanceof HostInfo)) {
+        if (!(other instanceof HostInfo)) {
             return false;
         }
         if (other == this) {
