@@ -97,6 +97,30 @@ public class Constants {
      */
     public static final String PIPELINE_NAME = "pipeline.name";
 
+    /**
+     * https://nightlies.apache.org/flink/flink-docs-master/docs/dev/table/config/
+     * default AUTO
+     */
+    public static final String TABLE_EXEC_SINK_UPSERT_MATERIALIZE = "table.exec.sink.upsert-materialize";
+
+    public static final ConfigOption<String> UPSERT_MATERIALIZE =
+            key("table.exec.sink.upsert-materialize").defaultValue("AUTO").withDescription("Because of the disorder "
+                    + "of ChangeLog data caused by Shuffle in distributed system, the data received by Sink may not "
+                    + "be the order of global upsert. So add upsert materialize operator before upsert sink. It "
+                    + "receives the upstream changelog records and generate an upsert view for the downstream.\n"
+                    + "By default, the materialize operator will be added when a distributed disorder occurs on "
+                    + "unique keys. You can also choose no materialization(NONE) or force materialization(FORCE).");
+
+    public static final String TABLE_EXEC_SINK_NOT_NULL_ENFORCER = "table.exec.sink.not-null-enforcer";
+
+    public static final ConfigOption<String> NOT_NULL_ENFORCER =
+            key("table.exec.sink.not-null-enforcer").defaultValue("ERROR").withDescription("Determines how Flink "
+                    + "enforces NOT NULL column constraints when inserting null values.\n"
+                    + "Possible values:\n"
+                    + "\"ERROR\": Throw a runtime exception when writing null values into NOT NULL column.\n"
+                    + "\"DROP\": Drop records silently if a null value would have to be inserted into a NOT NULL "
+                    + "column.");
+
     /**
      * The ID of the cluster, used to separate multiple clusters.
      */
@@ -319,8 +343,8 @@ public class Constants {
 
     public static final String CHDFS_CONFIG_PREFIX = "fs.ofs.";
 
-    public static final ConfigOption<Boolean> LIGHTWEIGHT = key("lightweight").defaultValue(false)
-            .withDescription("Whether to lightweight or not");
+    public static final ConfigOption<Boolean> DATASYNC = key("datasync").defaultValue(false)
+            .withDescription("Whether to datasync or not");
 
     public static final ConfigOption<String> GROUP_INFO_FILE = key("group.info.file").noDefaultValue()
             .withDescription("The file which contains group info for a single tenant job");
